@@ -5,22 +5,23 @@
 #
 # See detailed description in lctut.html
 
-set -x
-
 # data
 wget -nv ftp://munipack.physics.muni.cz/pub/munipack/munipack-data-0716.tar.gz
 tar zxf munipack-data-0716.tar.gz
-DATA=${PWD}/munipack-data-0716/
+DATADIR=$(pwd)/munipack-data-0716/
+
 mkdir workdir-0716/
 cd workdir-0716/
 
 # preprocessing
-munipack dark -o d30.fits $DATA/d30_*.fits
-munipack dark -o d120.fits $DATA/d120_*.fits
-munipack flat -o f_V.fits -dark d30.fits $DATA/f30_*V.fits
-munipack flat -o f_R.fits -dark d30.fits $DATA/f30_*R.fits
-munipack phcorr -dark d120.fits -flat f_V.fits -t . $DATA/0716_*V.fits
-munipack phcorr -dark d120.fits -flat f_R.fits -t . $DATA/0716_*R.fits
+munipack dark -o d30.fits $DATADIR/d30_*.fits
+munipack dark -o d120.fits $DATADIR/d120_*.fits
+munipack flat -o f_V.fits -dark d30.fits $DATADIR/f30_*V.fits
+munipack flat -o f_R.fits -dark d30.fits $DATADIR/f30_*R.fits
+
+OPT="--enable-overwrite"
+munipack phcorr -dark d120.fits -flat f_V.fits $OPT -t . $DATADIR/0716_*V.fits
+munipack phcorr -dark d120.fits -flat f_R.fits $OPT -t . $DATADIR/0716_*R.fits
 
 # aperture photometry and star detection
 munipack find -f 3 0716_*.fits
