@@ -2,7 +2,7 @@
 
   Artificial frames
 
-  Copyright © 2016-22 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2016-23 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -42,12 +42,8 @@ bool Munipack::artificial(MuniProcess *action, MuniCmdLineParser& cmd)
 
   if( cmd.Found("phsystab",&a) )
     action->Write("PHSYSTABLE = '" + a + "'");
-#ifdef MUNIPACK_DATA_DIR
-  else {
-    wxFileName fname(MUNIPACK_DATA_DIR,"photosystems.fits");
-    action->Write("PHSYSTABLE = '"+fname.GetFullPath()+"'");
-  }
-#endif
+  else if( FindDataDir("photosystems.fits",&a) )
+    action->Write("PHSYSTABLE = '" + a + "'");
 
   if( cmd.Found("psf",&a) )
     action->Write("PROFILE = '" + a.Upper() + "'");
@@ -121,6 +117,9 @@ bool Munipack::artificial(MuniProcess *action, MuniCmdLineParser& cmd)
   if( cmd.Found("qeff",&x) )
     action->Write("QEFF = %lf",x);
 
+  if( cmd.Found("gnoise",&x) )
+    action->Write("GNOISE = %lf",x);
+
   if( cmd.Found("extk",&x) )
     action->Write("EXTINK = %lf",x);
 
@@ -175,37 +174,47 @@ bool Munipack::artificial(MuniProcess *action, MuniCmdLineParser& cmd)
 
   if( cmd.Found("c",&cname) || cmd.Found("cat",&cname) ) {
 
-      VOCatConf catalogs;
-      VOCatResources cat(catalogs.GetCatFits(cname));
+    //    VOCatConf catalogs;
+    //    VOCatResources cat(catalogs.GetCatFits(cname));
 
-      if( cmd.Found("col-ra",&a) )
-	action->Write("COL_RA = '" + a + "'");
-      else if( cat.IsOk() )
-	action->Write("COL_RA = '" + cat.GetLabel("POS_EQ_RA") + "'");
+    wxString vocat;
 
-      if( cmd.Found("col-dec",&a) )
-	action->Write("COL_DEC = '" + a + "'");
-      else if( cat.IsOk() )
-	action->Write("COL_DEC = '" + cat.GetLabel("POS_EQ_DEC") + "'");
+    if( cmd.Found("vocat",&a) )
+      vocat = a;
+    else if( FindDataDir("VOcat_conf.xml",&a) )
+      vocat = a;
 
-      if( cmd.Found("col-pm-ra",&a) )
-	action->Write("COL_PMRA = '" + a + "'");
-      else if( cat.IsOk() )
-	action->Write("COL_PMRA = '" + cat.GetLabel("POS_EQ_PMRA") + "'");
+    VOCatConf catalogs(vocat);
+    VOCatResources cat(catalogs.GetCatFits(cname));
 
-      if( cmd.Found("col-pm-dec",&a) )
-	action->Write("COL_PMDEC = '" + a + "'");
-      else if( cat.IsOk() )
-	action->Write("COL_PMDEC = '" + cat.GetLabel("POS_EQ_PMDEC") + "'");
+    if( cmd.Found("col-ra",&a) )
+      action->Write("COL_RA = '" + a + "'");
+    else if( cat.IsOk() )
+      action->Write("COL_RA = '" + cat.GetLabel("POS_EQ_RA") + "'");
 
-      if( cmd.Found("col-mag",&a) )
-	action->Write("COL_MAG = '" + a + "'");
-      else if( filter != "" )
-	action->Write("COL_MAG = '" + filter + "mag'");
-      else if( cat.IsOk() )
-	action->Write("COL_MAG = '" + cat.GetSort() + "'");
+    if( cmd.Found("col-dec",&a) )
+      action->Write("COL_DEC = '" + a + "'");
+    else if( cat.IsOk() )
+      action->Write("COL_DEC = '" + cat.GetLabel("POS_EQ_DEC") + "'");
 
-      action->Write("CAT = '" + cname + "'");
+    if( cmd.Found("col-pm-ra",&a) )
+      action->Write("COL_PMRA = '" + a + "'");
+    else if( cat.IsOk() )
+      action->Write("COL_PMRA = '" + cat.GetLabel("POS_EQ_PMRA") + "'");
+
+    if( cmd.Found("col-pm-dec",&a) )
+      action->Write("COL_PMDEC = '" + a + "'");
+    else if( cat.IsOk() )
+      action->Write("COL_PMDEC = '" + cat.GetLabel("POS_EQ_PMDEC") + "'");
+
+    if( cmd.Found("col-mag",&a) )
+      action->Write("COL_MAG = '" + a + "'");
+    else if( filter != "" )
+      action->Write("COL_MAG = '" + filter + "mag'");
+    else if( cat.IsOk() )
+      action->Write("COL_MAG = '" + cat.GetSort() + "'");
+
+    action->Write("CAT = '" + cname + "'");
   }
 
   if( cmd.Found("galcat",&cname) ) {
