@@ -149,7 +149,14 @@ bool Munipack::astrometry(MuniProcess *action, MuniCmdLineParser& cmd)
 
     if( cone != "" && ! mancal) {
 
-      VOCatConf catalogs;
+      wxString a,vocat;
+
+      if( cmd.Found("vocat",&a) )
+	vocat = a;
+      else if( FindDataDir("VOcat_conf.xml",&a) )
+	vocat = a;
+
+      VOCatConf catalogs(vocat);
       VOCatResources cat(catalogs.GetCatFits(cone));
 
       if( cmd.Found("col-ra",&a) )
