@@ -2,7 +2,7 @@
 
   Munipack - command line parser
 
-  Copyright © 2010-19, 2022 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2010-19, 2022-23 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -245,7 +245,7 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc,
     AddOption("","server","Virtual observatory server (see --list-servers)");
     AddSwitch("","list-catalogues","show available catalogues");
     AddSwitch("","list-servers","show available VO servers");
-    AddOption("","vocat","configuration file");
+    AddOption("","vocat","VO catalogue config file (column IDs)");
     AddOption("","type","type of output file: fits,xml");
     COMMON_OPTIONS_SINGLE
     AddParam("ra",wxCMD_LINE_VAL_DOUBLE,wxCMD_LINE_PARAM_OPTIONAL);
@@ -335,6 +335,7 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc,
     AddSwitch(wxEmptyString,"disable-save","don't save calibration to header");
     AddSwitch(wxEmptyString,"remove","remove complete astrometry calibration");
     AddSwitch(wxEmptyString,"show-defaults","show defaults");
+    AddOption("","vocat","VO catalogue config file (column IDs)");
     COMMON_OPTIONS_MULTIPLE
     AddParam("file(s)[,results(s)]",wxCMD_LINE_VAL_STRING,
 	     wxCMD_LINE_PARAM_OPTIONAL|wxCMD_LINE_PARAM_MULTIPLE);
@@ -572,6 +573,7 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc,
     AddSwitch(wxEmptyString,"list","show available photometry systems");
     AddOption(wxEmptyString,"tol","search radius [deg]",wxCMD_LINE_VAL_DOUBLE);
     AddOption("","saper","select aperture number",wxCMD_LINE_VAL_NUMBER);
+    AddOption("","vocat","VO catalogue config file (column IDs)");
     COMMON_OPTIONS_MULTIPLE
     AddParam("file(s)[,results(s)]",wxCMD_LINE_VAL_STRING,
   	     wxCMD_LINE_PARAM_MULTIPLE|wxCMD_LINE_PARAM_OPTIONAL);
@@ -643,6 +645,7 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc,
 	      wxCMD_LINE_VAL_DOUBLE);
     AddOption("","exptime","exposure time [s]",wxCMD_LINE_VAL_DOUBLE);
     AddOption("","qeff","quantum efficiency",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","gnoise","add gaussian noise",wxCMD_LINE_VAL_DOUBLE);
     AddSwitch("","atmosphere","apply atmosphere modelling: extinction+seeing");
     AddOption("","extk","extinction coefficient",wxCMD_LINE_VAL_DOUBLE);
     AddOption("","long","geographic longitude of station (+east)[deg]",
@@ -677,6 +680,7 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc,
     AddSwitch("","disable-noise","noise free frames");
     AddOption("","photsys","photometry system");
     AddOption("","phsystab","photometry systems definition table");
+    AddOption("","vocat","VO catalogue config file (column IDs)");
     AddOption("","mask","mask for output files (artificial_???.fits)");
     COMMON_OPTIONS_BITPIX
   }
