@@ -2,7 +2,7 @@
 
   Munipack - command line interface
 
-  Copyright © 2012-3, 2018-9 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2012-3, 2018-9, 2023 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -313,3 +313,24 @@ bool Munipack::SetTargetDir(const wxString& t)
   else
     return false;
 }
+
+bool Munipack::FindDataDir(const wxString& file, wxString *filepath) const
+{
+  wxString dir;
+
+  if( wxGetEnv("MUNIPACK_DATA_DIR",&dir) == false ) {
+#ifdef MUNIPACK_DATA_DIR
+    dir = wxString(MUNIPACK_DATA_DIR);
+#endif
+  }
+
+  wxFileName path(dir,file);
+  if( path.FileExists() ) {
+    *filepath = path.GetFullPath();
+    return true;
+  }
+
+  wxLogError("Munipack::FindDataDir(): an improper setup of MUNIPACK_DATA_DIR=`"
+	     +dir+"' for file: `"+file+"'");
+  return false;
+}
