@@ -7,7 +7,7 @@
   * file-existing
 
 
-  Copyright © 2013 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2013, 2018 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -15,12 +15,12 @@
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
-  
+
   Munipack is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with Munipack.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -32,20 +32,14 @@ class FITSFileName
 {
 public:
   FITSFileName(const wxString&);
-  wxString GetBackup() const;
-  wxString GetBaseName() const;
-  bool FileExists() const;
-
-  void SetSuffix(const wxString&);
-  void SetControl(const wxString&);
-
-  static bool ParseExt(const wxString&, wxString&,wxString&);
+  wxString GetFullName() const;
+  wxString GetType() const { return filetype; }
+  wxString GetFullPath() const { return fullpath; }
+  bool IsOk() const { return status == 0; }
 
 private:
 
-  wxString filename,backup,version_control,simple_backup_suffix;
+  int status;
+  wxString filename, filetype, fullpath, tmpname, suffix;
 
-  wxString Get(const wxString&) const;
-  long FindBackup(const wxString&) const;
-  wxString NumberBackup(const wxString&,long) const;
 };
