@@ -2,7 +2,7 @@
 
   Average of flats.
 
-  Copyright © 2010-2014, 2017 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2010-2014, 2017-8 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -28,6 +28,8 @@ bool Munipack::flat(MuniProcess *action, MuniCmdLineParser& cmd)
 {
   CommonOutputSingle(action,cmd);
   CommonOptionsBitpix(action,cmd);
+  CommonOptionsPhCorr(action,cmd);
+  EnvironmentPhCorr(action);
 
   double x;
   wxString a;
@@ -41,28 +43,13 @@ bool Munipack::flat(MuniProcess *action, MuniCmdLineParser& cmd)
   if( cmd.Found("xdark",&x) )
     action->Write("XDARK = %lf",x);
 
-  if( cmd.Found("bitmask",&a) )
-    action->Write("MASK = '"+a+"'");
-
   if( cmd.Found("gain",&x) )
     action->Write("GAIN = %lf",x);
 
-  if( cmd.Found("st",&x) || cmd.Found("saturate",&x) )
-    action->Write("SATURATE = %lf",x);
-
-  if( cmd.Found("th",&x) || cmd.Found("threshold",&x) )
-    action->Write("THRESHOLD = %lf",x);
-
-  if( cmd.Found("gain-estimate") ) {
-    action->Write("GAIN_ESTIMATE = T");
-    action->Write("VERBOSE = T");
-  }
-
   if( cmd.Found("approximation",&a) )
-    action->Write("APPROXIMATION = '"+a+"'");
+    action->Write("APPROXIMATION = '" + a.Upper() + "'");
 
-  for(size_t i = 0; i < cmd.GetParamCount(); i++)
-    WriteFile(action,cmd.GetParam(i));
+  WriteFiles(action,cmd.GetFiles());
 
   return true;
 }
