@@ -2,7 +2,7 @@
 
   Photometric calibration
 
-  Copyright © 2012-9 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2012-23 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -29,6 +29,8 @@
 
 bool Munipack::phcal(MuniProcess *action, MuniCmdLineParser& cmd)
 {
+  wxString vocat;
+
   CommonOutputMultiple(action,cmd);
 
   wxString a;
@@ -40,12 +42,13 @@ bool Munipack::phcal(MuniProcess *action, MuniCmdLineParser& cmd)
 
   if( cmd.Found("phsystab",&a) )
     action->Write("PHSYSTABLE = '" + a + "'");
-#ifdef MUNIPACK_DATA_DIR
-  else {
-    wxFileName fname(MUNIPACK_DATA_DIR,"photosystems.fits");
-    action->Write("PHSYSTABLE = '"+fname.GetFullPath()+"'");
-  }
-#endif
+  else if( FindDataDir("photosystems.fits",&a) )
+    action->Write("PHSYSTABLE = '" + a + "'");
+
+  if( cmd.Found("vocat",&a) )
+    vocat = a;
+  else if( FindDataDir("VOcat_conf.xml",&a) )
+    vocat = a;
 
   if( cmd.Found("list") )
 
@@ -127,7 +130,7 @@ bool Munipack::phcal(MuniProcess *action, MuniCmdLineParser& cmd)
 
     if( cmd.Found("c",&c) || cmd.Found("cat",&c) ) {
 
-      VOCatConf catalogs;
+      VOCatConf catalogs(vocat);
       VOCatResources cat(catalogs.GetCatFits(c));
 
       if( cmd.Found("col-ra",&a) )
