@@ -2,7 +2,7 @@
 
   Photometric system transformation
 
-  Copyright © 2013 - 15, 2018 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2013 - 15, 2018, 2022 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -36,12 +36,8 @@ bool Munipack::phfotran(MuniProcess *action, MuniCmdLineParser& cmd)
 
   if( cmd.Found("phsystab",&a) )
     action->Write("PHSYSTABLE = '" + a + "'");
-#ifdef MUNIPACK_DATA_DIR
-  else {
-    wxFileName fname(MUNIPACK_DATA_DIR,"photosystems.fits");
-    action->Write("PHSYSTABLE = '"+fname.GetFullPath()+"'");
-  }
-#endif
+  else if( FindDataDir("photosystems.fits",&a) )
+    action->Write("PHSYSTABLE = '" + a + "'");
 
   if( cmd.Found("list") )
 
