@@ -128,10 +128,7 @@ mpInfoLayer::mpInfoLayer(wxRect rect, const wxBrush* brush) : m_dim(rect)
     m_type = mpLAYER_INFO;
 }
 
-mpInfoLayer::~mpInfoLayer()
-{
-
-}
+//mpInfoLayer::~mpInfoLayer() {}
 
 void mpInfoLayer::UpdateInfo(mpWindow& w, wxEvent& event)
 {
@@ -208,10 +205,7 @@ mpInfoCoords::mpInfoCoords(wxRect rect, const wxBrush* brush) : mpInfoLayer(rect
 
 }
 
-mpInfoCoords::~mpInfoCoords()
-{
-
-}
+//mpInfoCoords::~mpInfoCoords() { }
 
 void mpInfoCoords::UpdateInfo(mpWindow& w, wxEvent& event)
 {
@@ -273,10 +267,7 @@ mpInfoLegend::mpInfoLegend(wxRect rect, const wxBrush* brush) : mpInfoLayer(rect
 
 }
 
-mpInfoLegend::~mpInfoLegend()
-{
-
-}
+// mpInfoLegend::~mpInfoLegend() {}
 
 void mpInfoLegend::UpdateInfo(mpWindow& w, wxEvent& event)
 {
@@ -693,7 +684,7 @@ void mpProfile::Plot(wxDC & dc, mpWindow & w)
 			}
 		dc.DrawLine(i, c0, i+1, c1);
 		};
-		if (!m_name.IsEmpty()) {
+	if (!m_name.IsEmpty() && m_showName) {
 			dc.SetFont(m_font);
 
 			wxCoord tx, ty;
@@ -1180,7 +1171,7 @@ mpWindow::mpWindow( wxWindow *parent, wxWindowID id, const wxPoint &pos, const w
     m_minX   = m_minY   = 0;
     m_maxX   = m_maxY   = 0;
     m_last_lx= m_last_ly= 0;
-    m_buff_bmp = NULL;
+    m_buff_bmp = wxBitmap();
     m_enableDoubleBuffer        = FALSE;
     m_enableMouseNavigation     = TRUE;
     m_mouseMovedAfterRightClick = FALSE;
@@ -1188,7 +1179,6 @@ mpWindow::mpWindow( wxWindow *parent, wxWindowID id, const wxPoint &pos, const w
     // Set margins to 0
     m_marginTop = 0; m_marginRight = 0; m_marginBottom = 0; m_marginLeft = 0;
 
-
     m_lockaspect = FALSE;
 
     m_popmenu.Append( mpID_CENTER,     _("Center"),      _("Center plot view to this position"));
@@ -1207,21 +1197,16 @@ mpWindow::mpWindow( wxWindow *parent, wxWindowID id, const wxPoint &pos, const w
     SetSizeHints(128, 128);
 
     // J.L.Blanco: Eliminates the "flick" with the double buffer.
-    SetBackgroundStyle( wxBG_STYLE_CUSTOM );
+    //    SetBackgroundStyle( wxBG_STYLE_CUSTOM );
+    SetBackgroundStyle( wxBG_STYLE_PAINT );
 
     UpdateAll();
 }
 
 mpWindow::~mpWindow()
 {
-	// Free all the layers:
-	DelAllLayers( true, false );
-
-    if (m_buff_bmp)
-    {
-        delete m_buff_bmp;
-        m_buff_bmp = NULL;
-    }
+  // Free all the layers:
+  DelAllLayers( true, false );
 }
 
 // Mouse handler, for detecting when the user drag with the right button or just "clicks" for the menu
@@ -1772,15 +1757,19 @@ void mpWindow::OnPaint( wxPaintEvent& WXUNUSED(event) )
 
     // Selects direct or buffered draw:
     wxDC    *trgDc;
+    wxMemoryDC  m_buff_dc;
 
     // J.L.Blanco @ Aug 2007: Added double buffer support
     if (m_enableDoubleBuffer)
     {
         if (m_last_lx!=m_scrX || m_last_ly!=m_scrY)
         {
+	  /*
             if (m_buff_bmp) delete m_buff_bmp;
             m_buff_bmp = new wxBitmap(m_scrX,m_scrY);
-            m_buff_dc.SelectObject(*m_buff_bmp);
+	    */
+	    m_buff_bmp = wxBitmap(m_scrX,m_scrY);
+            m_buff_dc.SelectObject(m_buff_bmp);
             m_last_lx=m_scrX;
             m_last_ly=m_scrY;
         }
@@ -2304,7 +2293,8 @@ bool mpWindow::IsLayerVisible(const unsigned int position )
 
 void mpWindow::SetColourTheme(const wxColour& bgColour, const wxColour& drawColour, const wxColour& axesColour)
 {
-	 SetBackgroundColour(bgColour);
+  /* dangerous under GTK3, interferes with theme ? */
+  SetBackgroundColour(bgColour);
 	 SetForegroundColour(drawColour);
 	 m_bgColour = bgColour;
 	 m_fgColour = drawColour;
