@@ -2,7 +2,7 @@
 
   xmunipack - config
 
-  Copyright © 2012-5, 2019-22 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2012-2025 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -237,27 +237,9 @@ MuniConfig::MuniConfig(const wxString& config_file):
   Read(COLOUR_DISPLAY, &display_colourspace, "sRGB");
   Read(DISPLAY_BGCOLOUR, &display_bgcolour, "grey15");
 
-  Read(CDATAFILE, &cdatafile, "");
-  Read(PHSYSTEMFILE, &phsystemfile, "");
-
-#ifdef MUNIPACK_DATA_DIR
-  wxFileName ctab(cdatafile);
-  if( ! ctab.IsFileReadable() ) {
-    wxFileName cpath(MUNIPACK_DATA_DIR,"ctable.dat");
-    if( cpath.FileExists() )
-      cdatafile = cpath.GetFullPath();
-    else
-      wxPrintf("%s: Improper setup. Please, set ctable manually.\n",__FILE__);
-  }
-  wxFileName phtab(phsystemfile);
-  if( ! phtab.IsFileReadable() ) {
-    wxFileName phpath(MUNIPACK_DATA_DIR,"photosystems.fits");
-    if( phpath.FileExists() )
-       phsystemfile = phpath.GetFullPath();
-    else
-      wxPrintf("%s: Improper setup. Please, set phsystems manually.\n",__FILE__);
-  }
-#endif
+  cdatafile = FindDataDir("ctable.dat");
+  phsystemfile = FindDataDir("photosystems.fits");
+  munipack_html_dir = FindHtmlDir("munipack.html");
 
   default_symbol = "?";
   head_symbol = L"🦉";
@@ -363,12 +345,50 @@ MuniConfig::~MuniConfig()
   Write(FITS_KEY_AREA,fits_key_area);
   Write(DISPLAY_BGCOLOUR,display_bgcolour);
   Write(COLOUR_DISPLAY,display_colourspace);
-  Write(CDATAFILE,cdatafile);
-  Write(PHSYSTEMFILE,phsystemfile);
 
   wxLogDebug("MuniConfig::~MuniConfig()");
 }
 
+wxString MuniConfig::FindDataDir(const wxString& file)
+{
+  wxString dir;
+
+  if( wxGetEnv("MUNIPACK_DATA_DIR",&dir) == false ) {
+#ifdef MUNIPACK_DATA_DIR
+    dir = wxString(MUNIPACK_DATA_DIR);
+#endif
+  }
+
+  wxFileName path(dir,file);
+  if( path.FileExists() )
+    return path.GetFullPath();
+
+  // fail-back
+  wxPrintf("%s: an improper setup. Please, set MUNIPACK_DATA_DIR.\n",__FILE__);
+  return "";
+}
+
+wxString MuniConfig::FindHtmlDir(const wxString& file)
+{
+  wxString dir;
+
+  if( wxGetEnv("MUNIPACK_HTML_DIR",&dir) == false ) {
+#ifdef MUNIPACK_HTML_DIR
+    dir = wxString(MUNIPACK_HTML_DIR);
+#endif
+  }
+
+  wxFileName path(dir,file);
+  if( path.FileExists() )
+    return path.GetFullPath();
+
+  // fail-back
+  /* The help is inactive currently. */
+  //  wxPrintf("%s: an improper setup. Please, set MUNIPACK_HTML_DIR.\n",__FILE__);
+  return "";
+}
+
+
 wxString MuniConfig::FindIconPath(const wxString& name)
 {
   wxArrayString p;
@@ -378,6 +398,10 @@ wxString MuniConfig::FindIconPath(const wxString& name)
 #endif
 
   wxPathList paths(p);
+  wxString dir;
+
+  if( wxGetEnv("MUNIPACK_ICON_DIR",&dir) )
+    paths.Add(dir);
 
 #ifdef MUNIPACK_ICON_DIR
   paths.Add(MUNIPACK_ICON_DIR);
