@@ -2,7 +2,7 @@
 
   xmunipack - display image
 
-  Copyright © 2009-2013, 2017-2022 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2009-2013, 2017-2024 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -441,7 +441,6 @@ void MuniDisplay::OnMouseEnter(wxMouseEvent& event)
   MuniSlewEvent evt(EVT_SLEW);
   evt.entering = true;
   wxQueueEvent(GetParent(),evt.Clone());
-  SetFocus();
 }
 
  void MuniDisplay::OnMouseLeave(wxMouseEvent& event)
@@ -449,7 +448,6 @@ void MuniDisplay::OnMouseEnter(wxMouseEvent& event)
   MuniSlewEvent evt(EVT_SLEW);
   evt.leaving = true;
   wxQueueEvent(GetParent(),evt.Clone());
-  GetParent()->SetFocus();
 }
 
 
