@@ -2,7 +2,7 @@
 
   xmunipack - empirical cummulative distribution function
 
-  Copyright © 2018-2022 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2018-2025 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -25,27 +25,29 @@
 #include <cstdio>
 #include <cstring>
 #include <cmath>
-#include <cfloat>
+#include <limits>
 #include <algorithm>
 
 using namespace std;
 
-
-
 // cumulative distribution function of data
 EmpiricalCDF::EmpiricalCDF(long n, const float *data): ncdf(0),xcdf(0),ycdf(0)
 {
+  const double macheps = std::numeric_limits<float>::epsilon();
   wxASSERT(n > 0 && data);
-  //  wxLogDebug("EmpiricalCDF::EmpiricalCDF(long n, const float *data):");
+  //wxLogDebug("EmpiricalCDF::EmpiricalCDF(long n, const float *data):");
 
   float *d = new float[n];
   copy(data,data+n,d);
   sort(d,d+n);
 
-  // remove duplicite points
-  long m = 1; // see assumption n > 0 above
-  for(long i = 1; i < n; i++) {
-    if( fabsf(d[i] - d[m]) > 10*FLT_EPSILON )
+  // remove duplicite points + Nans + Infs
+  long m = 0;
+  long k = 0;
+  while( !isfinite(d[k]) && k < n ) k++;
+  d[0] = d[k];
+  for(long i = k; i < n; i++) {
+    if( fabsf(d[i] - d[m]) > 2*macheps && isfinite(d[i]) )
       d[m++] = d[i];
   }
 
@@ -63,6 +65,8 @@ EmpiricalCDF::EmpiricalCDF(long n, const float *data): ncdf(0),xcdf(0),ycdf(0)
     fprintf(f,"%f %f\n",xcdf[i],ycdf[i]);
   fclose(f);
   */
+  //  wxLogFatalError("ss");
+
 
   delete[] d;
 }
@@ -115,6 +119,7 @@ bool EmpiricalCDF::IsOk() const
 
 float EmpiricalCDF::GetQuantile(float q) const
 {
+  const double macheps = std::numeric_limits<float>::epsilon();
   wxASSERT(xcdf && ycdf);
 
   long n = ncdf;
@@ -132,15 +137,15 @@ float EmpiricalCDF::GetQuantile(float q) const
     float h = 1.0 / float(n + 1);
     float r = q / h;
     int m = round(r);
-    if( fabsf(m - r) < 10*FLT_EPSILON )
+    if( fabsf(m - r) < 10*macheps )
       return xcdf[m];
     else {
       int low = int(r);
       int high = low + 1;
-      //wxLogDebug("%d %d %ld %f %f",low,high,ncdf,q,h);
+      //      wxLogDebug("%d %d %ld %f %f",low,high,ncdf,q,h);
 
       float dy = ycdf[high] - ycdf[low];
-      if( fabsf(dy) > 10*FLT_EPSILON )
+      if( fabsf(dy) > 10*macheps )
 	// inverse by linear interpolation
 	return (xcdf[high] - xcdf[low])/dy*(q - ycdf[low]) + xcdf[low];
       else {
