@@ -2,7 +2,7 @@
 
   XMunipack - FITS headers
 
-  Copyright © 2009-2013, 2017-22 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2009-2025 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -625,10 +625,6 @@ class FitsTone
   float GetBlack() const { return black; }
   float GetQblack() const { return qblack; }
   float GetRsense() const { return rsense; }
-  float GetBlackMin() const;
-  float GetBlackMax() const;
-  float GetBackMed() const;
-  float GetBackSig() const;
   void Reset();
 
 };
