@@ -2,7 +2,7 @@
 
   xmunipack - fits implementation of statistics
 
-  Copyright © 2018 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2018-2021 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -22,33 +22,74 @@
 */
 
 #include "fits.h"
-#include <cstdio>
-#include <cstring>
-#include <fitsio.h>
-#include <cmath>
 #include <cfloat>
-#include <algorithm>
 #include <wx/wx.h>
+#include <limits>
 
 using namespace std;
 
 FitsArrayStat::FitsArrayStat(const FitsArray& a, int nskip):
-  FitsArray(a),statistics(false),
+  FitsArray(a),minmax_initialised(false),medmad_initialised(false),
   skip(nskip > 0 ? nskip : max(int(Npixels())/32768,1)),
   med(0.0),mad(0.0),xmin(0.0),xmax(0.0)
 {
-  FitsArrayData *data = static_cast<FitsArrayData *>(m_refData);
-  wxASSERT(data && data->array && data->naxes);
+  wxASSERT(PixelData() && Naxis() > 0);
+}
 
-  long nd = Npixels() / skip;
-  float *d = new float[nd+1];
+float FitsArrayStat::GetMin()
+{
+  if( ! minmax_initialised ) {
+    Setup_minimax();
+    minmax_initialised = true;
+  }
+  return xmin;
+}
+float FitsArrayStat::GetMax()
+{
+  if( ! minmax_initialised ) {
+    Setup_minimax();
+    minmax_initialised = true;
+  }
+  return xmax;
+}
 
+void FitsArrayStat::Setup_minimax()
+{
   // maximum, minimum
-  for(long i = 0, j = 0; j < nd; i++, j++) {
-    float x = Pixel(i);
+  xmin = numeric_limits<double>::max();
+  xmax = numeric_limits<double>::min();
+  const float *d = PixelData();
+  for(long i = 0; i < Npixels(); i++) {
+    float x = d[i];
     if( x > xmax ) xmax = x;
     if( x < xmin ) xmin = x;
   }
+  wxLogDebug("FitsArrayStat::Setup_minimax() %f %f",xmin,xmax);
+}
+
+
+float FitsArrayStat::GetMed()
+{
+  if( !medmad_initialised ) {
+    Setup_medmad();
+    medmad_initialised = true;
+  }
+  return med;
+}
+
+float FitsArrayStat::GetMad()
+{
+  if( !medmad_initialised ) {
+    Setup_medmad();
+    medmad_initialised = true;
+  }
+  return mad;
+}
+
+void FitsArrayStat::Setup_medmad()
+{
+  long nd = Npixels() / skip;
+  float *d = new float[nd+1];
 
   // median
   for(long i = 0, j = 0; j < nd; i += skip, j++) {
@@ -69,31 +110,9 @@ FitsArrayStat::FitsArrayStat(const FitsArray& a, int nskip):
 
   delete[] d;
 
-  wxLogDebug("stat: %f %f %ld %f %d",mad,med,n,Pixel(1),skip);
-  statistics = true;
+  wxLogDebug("Setup_medmad(): %f %f %ld %f %d",mad,med,n,Pixel(1),skip);
 }
 
-float FitsArrayStat::GetMed() const
-{
-  wxASSERT(statistics);
-  return med;
-}
-
-float FitsArrayStat::GetMad() const
-{
-  wxASSERT(statistics);
-  return mad;
-}
-float FitsArrayStat::GetMin() const
-{
-  wxASSERT(statistics);
-  return xmin;
-}
-float FitsArrayStat::GetMax() const
-{
-  wxASSERT(statistics);
-  return xmax;
-}
 
 float FitsArrayStat::QMed(long n, float *a, int k)
 {
