@@ -3,7 +3,7 @@
   xmunipack - head
 
 
-  Copyright © 2009-2011, 2020 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2009-2011, 2020-22 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -23,15 +23,15 @@
 */
 
 
-#include "xmunipack.h"
+#include "view.h"
 #include "help.h"
 #include <wx/wx.h>
 #include <wx/wfstream.h>
+#include <wx/txtstrm.h>
 
-
-MuniHead::MuniHead(wxWindow *w, MuniConfig *c):
-  wxTextCtrl(w,wxID_ANY,wxEmptyString, wxDefaultPosition, wxDefaultSize,
-	     wxTE_MULTILINE|wxTE_READONLY),config(c)
+MuniHead::MuniHead(wxWindow *w, const MuniConfig *c):
+  wxTextCtrl(w,wxID_ANY,"",wxDefaultPosition,wxDefaultSize,
+	     wxTE_MULTILINE|wxTE_READONLY|wxTE_DONTWRAP),config(c)
 {
   const wxFont *ft = wxNORMAL_FONT;
   wxFont tt = wxFont(ft->GetPointSize(),wxFONTFAMILY_MODERN,ft->GetStyle(),
@@ -41,6 +41,7 @@ MuniHead::MuniHead(wxWindow *w, MuniConfig *c):
   SetDefaultStyle(ta);
 }
 
+
 bool MuniHead::SetHdu(const FitsHdu& h)
 {
   head = h;
@@ -69,7 +70,6 @@ bool MuniHead::SetHdu(const FitsHdu& h)
 }
 
 
-
 // -----   MuniHeader ---------------------------------
 
 MuniHeader::MuniHeader(wxWindow *w, MuniConfig *c):
@@ -82,17 +82,19 @@ MuniHeader::MuniHeader(wxWindow *w, MuniConfig *c):
   menuFile->AppendSeparator();
   menuFile->Append(wxID_CLOSE);
 
+  /*
   menuEdit =  new wxMenu;
   menuEdit->Append(wxID_CUT);
   menuEdit->Append(wxID_COPY);
   menuEdit->Append(wxID_PASTE);
+  */
 
   wxMenu *menuHelp = new wxMenu;
   menuHelp->Append(wxID_ABOUT);
 
   wxMenuBar *menuBar = new wxMenuBar;
   menuBar->Append(menuFile,"&File");
-  menuBar->Append(menuEdit,"&Edit");
+  //  menuBar->Append(menuEdit,"&Edit");
   menuBar->Append(menuHelp,"&Help");
   SetMenuBar(menuBar);
 
@@ -101,19 +103,24 @@ MuniHeader::MuniHeader(wxWindow *w, MuniConfig *c):
   wxBoxSizer *topsizer = new wxBoxSizer(wxVERTICAL);
   topsizer->Add(header,wxSizerFlags(1).Expand());
   SetSizer(topsizer);
+  SetSizeHints(wxSize(30*GetCharWidth(),7*GetCharHeight()));
 
   // init state
+  /*
   menuFile->Enable(ID_EXPORT,false);
   menuEdit->Enable(wxID_CUT,false);
   menuEdit->Enable(wxID_COPY,false);
   menuEdit->Enable(wxID_PASTE,false);
+  */
 
   Bind(wxEVT_CLOSE_WINDOW,&MuniHeader::OnClose,this);
   Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniHeader::FileClose,this,wxID_CLOSE);
   Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniHeader::FileExport,this,ID_EXPORT);
+  /*
   Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniHeader::EditCut,this,wxID_CUT);
   Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniHeader::EditCopy,this,wxID_COPY);
   Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniHeader::EditPaste,this,wxID_PASTE);
+  */
 }
 
 void MuniHeader::OnClose(wxCloseEvent& event)
