@@ -2,7 +2,7 @@
 
   xmunipack - the help viewer headers
 
-  Copyright © 2019-20 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2019-22 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -33,4 +33,4 @@ public:
   MuniAbout(const wxIcon&);
 };
 
-bool MuniHelp(const wxString& ="");
+bool MuniHelp(const wxString&, const wxString& ="");
