@@ -70,7 +70,7 @@ public:
     fits_key_object, fits_key_dateobs,fits_key_exptime,
     fits_key_filter, fits_key_observer, fits_key_gain, fits_key_area,
     browser_labelkey, browser_sortkey,display_colourspace,display_bgcolour,
-    cdatafile,phsystemfile;
+    cdatafile, phsystemfile, munipack_html_dir;
   wxString backup_suffix;
   wxString default_symbol, head_symbol, image_symbol, table_symbol;
   wxIcon munipack_icon;
@@ -80,9 +80,11 @@ public:
   // Magnifier
   int magnifier_scale;
 
-  static wxString FindIconPath(const wxString& name);
+  static wxString FindIconPath(const wxString&);
   static wxIcon LoadIcon(const wxString&);
   static wxImage LoadImage(const wxString&);
+  static wxString FindDataDir(const wxString&);
+  static wxString FindHtmlDir(const wxString&);
 
 };
 
