@@ -2,7 +2,7 @@
 
   Base support for tools
 
-  Copyright © 2019-20 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2019-22 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -178,7 +178,7 @@ void MuniTool::OnTimer(wxTimerEvent& event)
 
 void MuniTool::OnHelp(wxCommandEvent& event)
 {
-  MuniHelp(manpage);
+  MuniHelp(config->munipack_html_dir,manpage);
 }
 
 void MuniTool::OnInfo(wxCommandEvent& event)
