@@ -4,7 +4,7 @@
   XMunipack - plotting
 
 
-  Copyright © 2012-14, 2019  F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2012-14, 2019-21  F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -26,10 +26,11 @@
 #ifndef _XMUNIPACK_PLOT_H_
 #define _XMUNIPACK_PLOT_H_
 
+#include "event.h"
 #include "mathplot.h"
 #include "fits.h"
+#include <plplot.h>
 #include <wx/wx.h>
-#include <vector>
 
 
 /*
@@ -62,41 +63,119 @@ public:
 // };
 
 
-class MuniPlotHisto: public mpWindow
-{
-  std::vector<FitsHisto> hlist;
-  int hmax;
-  double xmin,xmax;
-
-  void Plot();
-
-public:
-  MuniPlotHisto(wxWindow *);
-  wxSize DoGetBestSize() const;
-
-  void SetArray(const FitsArray&);
-  void SetArray(const std::vector<FitsArray>&);
-
-};
-
 /*
-class PlotNite: public wxPLplotwindow
+
+  A general wrapper for plplot with output to a memory with Cairo driver.
+  The user should implement MakeGraph() to provide a plotting function.
+
+ */
+class PlPlotCairo: public wxPanel
 {
+  wxImage graph;
+  bool ready;
+
+  void InitGraph();
+  void Plotter(bool=false);
+  void OnPaint(wxPaintEvent&);
+
 public:
-  PlotNite(wxWindow *);
-  wxSize DoGetBestSize() const;
+  PlPlotCairo(wxWindow *, const wxSize&);
+  void Update();
+  virtual void MakeGraph() = 0;
 
-  void SetColor(const FitsColor&);
-  void SetXrange(double, double);
-
-private:
-
-  FitsColor color;
-  float xmin,xmax;
-
-  void Plot();
 };
-*/
+
+
+class MuniPlotHistoBase: public PlPlotCairo
+{
+
+protected:
+  FitsHisto hist;
+  PLFLT xmin,xmax,ymin,ymax;
+  void StrokeHistoProfile(int, int, PLINT&, PLFLT*, PLFLT*);
+
+public:
+  MuniPlotHistoBase(wxWindow *, const wxSize&);
+  void SetHisto(const FitsHisto&);
+};
+
+
+class MuniPlotHisto: public MuniPlotHistoBase
+{
+  float black,sense;
+
+  void MakeGraph();
+
+public:
+  MuniPlotHisto(wxWindow *, const wxSize&, double, double);
+  void SetScale(double,double);
+};
+
+
+class MuniPlotNite: public MuniPlotHistoBase
+{
+  float level, width;
+  bool enabled;
+
+  void MakeGraph();
+  void MakePalette(PLFLT, PLINT, PLINT *, PLINT *, PLINT *);
+
+public:
+  MuniPlotNite(wxWindow *, const wxSize&, float, float, bool);
+  void SetMeso(float, float);
+  void SetEnabled(bool);
+
+};
+
+
+class MuniPlotItt: public PlPlotCairo
+{
+  FitsItt itt;
+
+  void MakeGraph();
+
+public:
+  MuniPlotItt(wxWindow *, const wxSize&, const FitsItt&);
+  void SetItt(int);
+};
+
+
+class MuniPlotPalette: public PlPlotCairo
+{
+  FitsPalette pal;
+  FitsItt itt;
+  float black, sense;
+
+  void MakeGraph();
+
+public:
+  MuniPlotPalette(wxWindow *, const wxSize&, int, bool, int, float, float);
+  void SetPalette(int);
+  void SetInverse(bool);
+  void SetItt(int);
+  void SetScale(float,float);
+};
+
+
+
+class MuniPlotSaturation: public PlPlotCairo
+{
+  float saturation;
+  float white_point[2];
+
+  void MakeGraph();
+  void MakeTable(PLFLT, PLFLT, PLINT, PLINT *, PLINT *, PLINT *);
+  void plfbox(PLFLT,PLFLT,PLFLT,PLFLT);
+  void plftri(PLFLT,PLFLT,PLFLT,PLFLT);
+
+public:
+  MuniPlotSaturation(wxWindow *, const wxSize&, float, float, float);
+  void SetSaturation(float);
+  void SetWhitePoint(float,float);
+
+};
+
+
 
 
 /*
