@@ -2,7 +2,7 @@
 /*
    xmunipack - time conversions
 
-   Copyright © 1997-2011, 2019 F.Hroch (hroch@physics.muni.cz)
+   Copyright © 1997-2011, 2019-2022 F.Hroch (hroch@physics.muni.cz)
 
    This file is part of Munipack.
 
@@ -99,7 +99,7 @@ void FitsTime::SetTime(const wxString& xtime)
   milisecond = long(1000.0*(sec - second));
 }
 
-double FitsTime::Jd() const
+double FitsTime::GetJd() const
 {
   double y,m,d,j;
 
