@@ -172,7 +172,7 @@ void MuniTune::FeedScaleTab(wxPanel *tpanel)
   wxSizerFlags entry_flags;
   entry_flags.Align(wxALIGN_CENTER_VERTICAL).Border(wxLEFT|wxRIGHT|wxTOP);
   wxSizerFlags button_flags;
-  button_flags.Align(wxALIGN_RIGHT|wxALIGN_CENTER_VERTICAL);
+  button_flags.Align(wxALIGN_CENTER_VERTICAL);
 
   wxFlexGridSizer *grid = new wxFlexGridSizer(4);
   grid->Add(new wxStaticText(tpanel,wxID_ANY,"Sensitivity:"),label_flags);
@@ -267,7 +267,7 @@ void MuniTune::FeedIttTab(wxPanel *tpanel)
   grid->Add(itt_photo,radio_flags);
 
   wxSizerFlags label_flags;
-  label_flags.Align(wxALIGN_RIGHT|wxALIGN_CENTER_VERTICAL).Border();
+  label_flags.Align(wxALIGN_CENTER_VERTICAL).Border();
 
   wxBoxSizer *fsizer = new wxBoxSizer(wxHORIZONTAL);
   fsizer->Add(new wxStaticText(tpanel,wxID_ANY,"Function:"),label_flags);
@@ -328,7 +328,7 @@ void MuniTune::FeedColourTab(wxPanel *panel)
 				  saturation,x_white,y_white);
 
   wxSizerFlags label_flags;
-  label_flags.Align(wxALIGN_RIGHT|wxALIGN_CENTER_VERTICAL).Border();
+  label_flags.Align(wxALIGN_CENTER_VERTICAL).Border();
   wxSizerFlags entry_flags;
   entry_flags.Align(wxALIGN_CENTER_VERTICAL).Border(wxLEFT|wxRIGHT|wxBOTTOM);
 
@@ -385,7 +385,7 @@ void MuniTune::FeedNiteTab(wxPanel *panel)
   wxSizerFlags entry_flags;
   entry_flags.Align(wxALIGN_CENTER_VERTICAL).Border(wxLEFT|wxRIGHT|wxBOTTOM);
   wxSizerFlags button_flags;
-  button_flags.Align(wxALIGN_RIGHT|wxALIGN_CENTER_VERTICAL);
+  button_flags.Align(wxALIGN_CENTER_VERTICAL);
 
   wxFlexGridSizer *grid = new wxFlexGridSizer(2);
   grid->Add(new wxStaticText(panel,wxID_ANY,"Mesopic level:"),label_flags);
@@ -463,10 +463,7 @@ void MuniTune::FeedPaletteTab(wxPanel *ppanel)
   grid->Add(pal_aips0,radio_flags);
 
   wxSizerFlags block_flags;
-  block_flags.Align(wxALIGN_RIGHT|wxALIGN_CENTER_VERTICAL).TripleBorder();
-
-  wxSizerFlags label_flags;
-  label_flags.Align(wxALIGN_RIGHT).Border(wxBOTTOM);
+  block_flags.Align(wxALIGN_CENTER_VERTICAL).TripleBorder();
 
   wxBoxSizer *fsizer = new wxBoxSizer(wxHORIZONTAL);
   fsizer->Add(grid,wxSizerFlags().Align(wxALIGN_CENTER|wxALIGN_CENTER_VERTICAL));
