@@ -2,7 +2,7 @@
 
   xmunipack - basic types for drawing
 
-  Copyright © 2012 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2012, 2019 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -21,23 +21,15 @@
 
 */
 
+#ifndef _XMUNIPACK_TYPES_H_
 #define _XMUNIPACK_TYPES_H_
 
-#ifndef _XMUNIPACK_ENUM_H_
+
 #include "enum.h"
-#endif
-
 #include <wx/wx.h>
+#include <vector>
 
 
-/*
-class MuniDrawBase: public wxObject
-{
-public:
-  MuniDrawBase() {}
-};
-*/
-
 class MuniDrawFont: public wxObject
 {
 public:
@@ -49,11 +41,8 @@ public:
 class MuniDrawPen: public wxObject
 {
 public:
-  //  MuniDrawPen(const wxColour& c, int w = 1): colour(c),width(w) {}
   MuniDrawPen(const wxPen& p): pen(p) {}
-  //  wxColour colour;
   wxPen pen;
-  //  int width;
 };
 
 class MuniDrawBrush: public wxObject
@@ -64,28 +53,35 @@ public:
   wxBrush brush;
 };
 
-class MuniDrawCircle: public wxObject//public MuniDrawBase
+class MuniDrawCircle: public wxObject
 {
 public:
   MuniDrawCircle(double xx, double yy, double rr):x(xx),y(yy),r(rr) {}
   double x,y,r;
 };
 
+class MuniDrawEllipse: public wxObject
+{
+public:
+ MuniDrawEllipse(double xx, double yy, double aa, double ee, double ii):
+  x(xx),y(yy),a(aa),e(ee),i(ii) {}
+  double x,y,a,e,i;
+};
+
+class MuniDrawRing: public wxObject
+{
+public:
+ MuniDrawRing(double xx, double yy, double r0, double r1):
+  x(xx),y(yy),rin(r0),rout(r1) {}
+  double x,y,rin,rout;
+};
+
+
 class MuniDrawLine: public wxObject
 {
 public:
   MuniDrawLine(double xx1, double yy1, double xx2, double yy2): x1(xx1),y1(yy1),x2(xx2),y2(yy2) {}
   double x1,y1,x2,y2;
-   /*
-n(2),points(new wxPoint2DDouble[n]) {
-    points[0] = wxPoint2DDouble(x1,y1);
-    points[1] = wxPoint2DDouble(x2,y2);
-   }
-  virtual ~MuniDrawLine() { delete[] points; }
-
-  size_t n;
-  wxPoint2DDouble *points;
-   */
 };
 
 class MuniDrawCross: public wxObject
@@ -133,10 +129,12 @@ public:
 class MuniLayer {
 public:
   MuniLayer(): id(ID_NULL) {}
+  MuniLayer(int i): id(i) {}
   MuniLayer(int i, const std::vector<wxObject *> o): id(i),objects(o) {}
 
   bool IsOk() { return id != ID_NULL && objects.size() > 0; }
   int GetId() const { return id; }
+  size_t IsEmpty() const { return objects.empty(); } // flag: to remove layer
   std::vector<wxObject *> GetObjects() const { return objects; }
 
 private:
@@ -145,3 +143,22 @@ private:
   std::vector<wxObject *> objects;
 
 };
+
+class MuniStarLayer
+{
+  const wxColour gold,DarkOrange2;
+  std::vector<wxObject *> objects;
+  double hwhm;
+
+ public:
+  MuniStarLayer();
+  MuniLayer GetLayer() const;
+  bool IsEmpty() const { return objects.empty(); }
+  void DrawObjects(const std::vector<double>&,const std::vector<double>&,
+		   const std::vector<double>&);
+  void SetHWHM(double x) { hwhm = x; }
+
+};
+
+
+#endif
