@@ -2,7 +2,7 @@
 
   xmunipack - main
 
-  Copyright © 2009-2015, 2019-20 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2009-2015, 2019-22 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -25,14 +25,7 @@
 #include <wx/wx.h>
 #include <wx/app.h>
 #include <wx/cmdline.h>
-#include <wx/debugrpt.h>
-#include <wx/protocol/ftp.h>
-#include <wx/wfstream.h>
-#include <cstdlib>
-
-#define FTP_LOGIN     "wxDebugReport"
-#define FTP_PASSWORD  "wxDebugReport"
-#define FTP_SERVER    "integral.physics.muni.cz"
+#include <wx/utils.h>
 
 
 wxIMPLEMENT_APP(XMunipack);
@@ -59,6 +52,8 @@ bool XMunipack::OnInit()
 
     if( cmd.Found("verbose") )
       wxLog::SetLogLevel(wxLOG_Debug);
+    else
+      wxSetAssertHandler(NULL);
 
     if( cmd.Found("version") ) {
       wxPrintf("%s %s, %s\n",PACKAGE_NAME,PACKAGE_VERSION,PACKAGE_COPYLEFT);
@@ -80,7 +75,29 @@ bool XMunipack::OnInit()
   // initialisation
   wxHandleFatalExceptions();
   wxInitAllImageHandlers();
-  config = new MuniConfig();
+
+  /*
+   https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html
+
+"$XDG_CONFIG_HOME defines the base directory relative to which user-specific configuration files should be stored. If $XDG_CONFIG_HOME is either not set or empty, a default equal to $HOME/.config should be used.
+"
+  */
+
+  wxString config_file;
+  wxString xdg_config_home;
+  if( wxGetEnv("XDG_CONFIG_HOME",&xdg_config_home) && xdg_config_home != "" ) {
+    wxFileName filename(xdg_config_home,"xmunipack.conf");
+    config_file = filename.GetFullPath();
+  }
+  else {
+    wxString home;
+    if( wxGetEnv("HOME",&home) && home != "" ) {
+      wxFileName filename(home,"xmunipack.conf");
+      filename.AppendDir(".config");
+      config_file = filename.GetFullPath();
+    }
+  }
+  config = new MuniConfig(config_file);
 
 #ifdef __WXMAC__
   // all main windows?
@@ -115,51 +132,9 @@ int XMunipack::OnExit()
 }
 
 
-void XMunipack::OnFatalException()
-{
-  wxDebugReport report;
-  wxDebugReportPreviewStd preview;
-
-  report.AddAll();
-
-  if ( preview.Show(report) ) {
-
-    // upload the report to home ftp
-    for(size_t i = 0; i < report.GetFilesCount(); i++) {
-      wxString name, desc;
-      report.GetFile(i,&name,&desc);
-      wxFileName file(report.GetDirectory(),name);
-
-      wxFTP ftp;
-      ftp.SetUser(FTP_LOGIN);
-      ftp.SetPassword(FTP_PASSWORD);
-
-      if ( !ftp.Connect(FTP_SERVER) ) {
-        wxLogError("Couldn't send bug report: Failed to connect.\n"
-		   "Leaving files in "+report.GetDirectory()+".\n");
-	report.Reset();
-        return;
-      }
-
-      wxDateTime dt(wxDateTime::Now());
-      dt.MakeUTC();
-      wxString oname(dt.Format("%Y-%m-%d_%H:%M:%S_")+name);
-      wxOutputStream *out = ftp.GetOutputStream(oname);
-      wxFileInputStream in(file.GetFullPath());
-      wxASSERT(in.IsOk() && out && out->IsOk());
-      if( out ) {
-	out->Write(in);
-	delete out;
-      }
-
-    }
-
-  }
-}
-
 void XMunipack::OnEventLoopEnter(wxEventLoopBase* WXUNUSED(loop))
 {
-  //  wxLogDebug("XMunipack::OnEventLoopEnter");
+  //wxLogDebug("XMunipack::OnEventLoopEnter");
   if( view )
     view->CreateFSWatch();
 }
